@@ -1,13 +1,12 @@
 output$serial1 <- renderAmCharts({
-  # prepare data
+  ##Data
   data <- as.data.table(get('Titanic', 'package:datasets'))
   data <- data[, .(freq = sum(N)), by = list(Sex, Survived)]
   (data <- split(data, f = data$Survived))
   setkey(data$Yes, Sex)
   setkey(data$No, Sex)
   (dp <- data$Yes[data$No])
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'Sex', startDuration = 0,
                   dataProvider = dp),
@@ -18,21 +17,20 @@ output$serial1 <- renderAmCharts({
     addValueAxis(stackType = '100%'),
     addTitle(text = 'Survivors to Titanic'),
     setLegend(useGraphSettings = TRUE),
-    setProperties(theme = input$theme_serial)
+    setProperties(theme = input$theme)
   )
 })
 
 output$code_serial1 <- renderText({
   "
-  # prepare data
+  ##Data
   data <- as.data.table(get('Titanic', 'package:datasets'))
   data <- data[, .(freq = sum(N)), by = list(Survived, Sex)]
   (data <- split(data, f = data$Sex))
   setkey(data$Male, Survived)
   setkey(data$Female, Survived)
   (dp <- data$Male[data$Female])
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'Survived', startDuration = 0,
                   dataProvider = dp),
@@ -48,7 +46,7 @@ output$code_serial1 <- renderText({
 })
 
 output$serial2 <- renderAmCharts({
-  # prepare data
+  ##Data
   dp <- data.table(year  =  c(2010, 2011, 2012, 2013, 2014),
                    income  =  c(20.4, 20.6, 24.3, 21.5, 22.3), 
                    expenses  =  c(31.5, 32.4, 25.6, 22.6, 24.9),
@@ -58,7 +56,7 @@ output$serial2 <- renderAmCharts({
   
   balloonText <- paste('<span style = \'font-size:12px;\'>[[title]] in [[category]]:',
                        '<br><span style = \'font-size:20px;\'>[[value]]</span> [[additional]]</span>')
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(addClassNames = TRUE, autoMargins = FALSE,
                   dataProvider = dp, marginLeft = 30, marginRight = 8,
@@ -82,7 +80,7 @@ output$serial2 <- renderAmCharts({
 
 output$code_serial2 <- renderText({
   "
-  # prepare data
+  ##Data
   dp <- data.table(year  =  c(2010, 2011, 2012, 2013, 2014),
                    income  =  c(20.4, 20.6, 24.3, 21.5, 22.3), 
                    expenses  =  c(31.5, 32.4, 25.6, 22.6, 24.9),
@@ -92,7 +90,7 @@ output$code_serial2 <- renderText({
   
   balloonText <- paste('<span style = \'font-size:12px;\'>[[title]] in [[category]]:',
                        '<br><span style = \'font-size:20px;\'>[[value]]</span> [[additional]]</span>')
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(addClassNames = TRUE, autoMargins = FALSE,
                   dataProvider = dp, marginLeft = 30, marginRight = 8,
@@ -116,7 +114,7 @@ output$code_serial2 <- renderText({
 })
 
 output$serial3 <- renderAmCharts({
-  # prepare data
+  ##Data
   dp <- data.table(
     country = c('USA', 'China', 'Japan', 'Germany', 'UK', 'France',
                 'India', 'Spain', 'Netherlands', 'Russia'), 
@@ -124,8 +122,7 @@ output$serial3 <- renderAmCharts({
     color = c('#FF0F00', '#FF6600', '#FF9E01', '#FCD202', '#F8FF01',
               '#B0DE09', '#04D215', '#0D8ECF', '#0D52D1', '#2A0CD0')
   )
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'country', dataProvider = dp,
                   depth3D = 40, angle = 30),
@@ -138,7 +135,7 @@ output$serial3 <- renderAmCharts({
 
 output$code_serial3 <- renderText({
   "
-  # prepare data
+  ##Data
   dp <- data.table(
     country = c('USA', 'China', 'Japan', 'Germany', 'UK', 'France',
                 'India', 'Spain', 'Netherlands', 'Russia'), 
@@ -146,8 +143,7 @@ output$code_serial3 <- renderText({
     color = c('#FF0F00', '#FF6600', '#FF9E01', '#FCD202', '#F8FF01',
               '#B0DE09', '#04D215', '#0D8ECF', '#0D52D1', '#2A0CD0')
   )
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'country', dataProvider = dp,
                   depth3D = 40, angle = 30),
@@ -160,7 +156,7 @@ output$code_serial3 <- renderText({
 })
 
 output$serial4 <- rAmCharts::renderAmCharts({
-  # prepare data
+  ##Data
   dp <- data.table(year = 1994:2012, 
                    cars = rnorm(length(1994:2012), mean = 10), 
                    motorcycles = rnorm(length(1994:2012), mean = 15), 
@@ -175,9 +171,7 @@ output$serial4 <- rAmCharts::renderAmCharts({
                'margin-right: 10px; width:28px; height:21px;\'>',
                '<span style = \'font-size:14px; color:#000000;\'>',
                '<b>[[value]]</b></span>')
-  
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(marginRight = 30, plotAreaBorderAlpha = 0, categoryField = 'year',
                   startDuration = 0, dataProvider = dp, theme = 'light'),
@@ -206,7 +200,7 @@ output$serial4 <- rAmCharts::renderAmCharts({
 
 output$code_serial4 <- renderText({
   "
-  # prepare data
+  ##Data
   dp <- data.table(year = 1994:2012, 
                    cars = rnorm(length(1994:2012), mean = 10), 
                    motorcycles = rnorm(length(1994:2012), mean = 15), 
@@ -221,9 +215,7 @@ output$code_serial4 <- renderText({
                'margin-right: 10px; width:28px; height:21px;\'>',
                '<span style = \'font-size:14px; color:#000000;\'>',
                '<b>[[value]]</b></span>')
-  
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(marginRight = 30, plotAreaBorderAlpha = 0, categoryField = 'year',
                   startDuration = 0, dataProvider = dp, theme = 'light'),
@@ -252,6 +244,7 @@ output$code_serial4 <- renderText({
 })
 
 output$serial5 <- renderAmCharts({
+  ##Plot
   pipeR::pipeline(
     amSerialChart(marginTop = 0, marginRight = 80, dataDateFormat = 'YYYY',
                   categoryField = 'year', startDuration = 0),
@@ -276,6 +269,7 @@ output$serial5 <- renderAmCharts({
 
 output$code_serial5 <- renderText({
   "
+  ##Plot
   pipeR::pipeline(
     amSerialChart(marginTop = 0, marginRight = 80, dataDateFormat = 'YYYY',
                   categoryField = 'year'),
@@ -300,11 +294,11 @@ output$code_serial5 <- renderText({
 })
 
 output$serial6 <- renderAmCharts({
-  # prepare data
-  dp <- data.table(binf = c(1,2,3,4,5),
-                   bsup = c(3,4,5,6,7),
-                   value = c(2,3,4,5,6),
-                   heure = c('9h','10h','11h','12h','13h'))
+  ##Data
+  dp <- data.table(binf = c(1, 2, 3, 4, 5),
+                   bsup = c(3, 4, 5,6, 7),
+                   value = c(2, 3, 4, 5, 6),
+                   heure = c('9h', '10h', '11h', '12h', '13h'))
   
   # prepare legend
   legend <- pipeR::pipeline(
@@ -320,8 +314,7 @@ output$serial6 <- renderAmCharts({
                                    'event.chart.showGraph(event.chart.getGraphById(id + \'_to\'));',
                                    '}'))
   )
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(legend = legend, dataProvider = dp, addClassNames=TRUE,
                   autoMargins = TRUE, startDuration = 0.5, categoryField = 'heure'),
@@ -341,11 +334,11 @@ output$serial6 <- renderAmCharts({
 
 output$code_serial6 <- renderText({
   "
-  # prepare data
-  dp <- data.table(binf = c(1,2,3,4,5),
-                   bsup = c(3,4,5,6,7),
-                   value = c(2,3,4,5,6),
-                   heure = c('9h','10h','11h','12h','13h'))
+  #Data
+  dp <- data.table(binf = c(1, 2, 3, 4, 5),
+                   bsup = c(3, 4, 5,6, 7),
+                   value = c(2, 3, 4, 5, 6),
+                   heure = c('9h', '10h', '11h', '12h', '13h'))
   
   # prepare legend
   legend <- pipeR::pipeline(
@@ -362,7 +355,7 @@ output$code_serial6 <- renderText({
                                    '}'))
   )
   
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(legend = legend, dataProvider = dp, addClassNames=TRUE,
                   autoMargins = TRUE, startDuration = 0.5, categoryField = 'heure'),
@@ -382,7 +375,7 @@ output$code_serial6 <- renderText({
 })
 
 output$serial7 <- renderAmCharts({
-  # prepare data
+  ##Data
   data <- as.data.table(get('Titanic', 'package:datasets'))
   data <- data[, .(freq = sum(N)), by = list(Sex, Survived)]
   (data <- split(data, f = data$Survived))
@@ -393,8 +386,7 @@ output$serial7 <- renderAmCharts({
     categoryAxis(gridPosition = 'start'),
     addListener('clickItem', 'function(event) {alert(\'Click on category axis\')}')
   )
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'Sex', startDuration = 0,
                   dataProvider = dp, categoryAxis = catAxis),
@@ -410,7 +402,7 @@ output$serial7 <- renderAmCharts({
 
 output$code_serial7 <- renderText({
   "
-  # prepare data
+  ##Data
   data <- as.data.table(get('Titanic', 'package:datasets'))
   data <- data[, .(freq = sum(N)), by = list(Sex, Survived)]
   (data <- split(data, f = data$Survived))
@@ -421,8 +413,7 @@ output$code_serial7 <- renderText({
     categoryAxis(gridPosition = 'start'),
     addListener('clickItem', 'function(event) {alert(\'Click on category axis\')}')
   )
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'Sex', startDuration = 0,
                   dataProvider = dp, categoryAxis = catAxis),
@@ -438,7 +429,7 @@ output$code_serial7 <- renderText({
 })
 
 output$serial8 <- renderAmCharts({
-  # prepare data
+  ##Data
   dp <- data.table(
     country = c('USA', 'China', 'Japan', 'Germany', 'UK', 'France',
                 'India', 'Spain', 'Netherlands', 'Russia'), 
@@ -450,8 +441,7 @@ output$serial8 <- renderAmCharts({
     chartCursor(categoryBalloonEnabled = FALSE, cursorAlpha = 0),
     addListener('zoomed', 'function(event) {alert(\'Zoom to some period\')}')
   )
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'country', dataProvider = dp,
                   chartCursor = chartCursor_obj),
@@ -463,7 +453,7 @@ output$serial8 <- renderAmCharts({
 
 output$code_serial8 <- renderText({
   "
-  # prepare data
+  ##Data
   dp <- data.table(
     country = c('USA', 'China', 'Japan', 'Germany', 'UK', 'France',
                 'India', 'Spain', 'Netherlands', 'Russia'), 
@@ -475,8 +465,7 @@ output$code_serial8 <- renderText({
     chartCursor(categoryBalloonEnabled = FALSE, cursorAlpha = 0),
     addListener('zoomed', 'function(event) {alert(\'Zoom to some period\')}')
   )
-  
-  # build the chart
+  ##Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'country', dataProvider = dp,
                   chartCursor = chartCursor_obj),
@@ -488,7 +477,7 @@ output$code_serial8 <- renderText({
 })
 
 output$serial9 <- renderAmCharts({
-  # prepare data
+  ##Data
   dp <- data.table(
     country = c('USA', 'China', 'Japan', 'Germany', 'UK', 'France',
                 'India', 'Spain', 'Netherlands', 'Russia'), 
@@ -497,8 +486,7 @@ output$serial9 <- renderAmCharts({
     color = c('#FF0F00', '#FF6600', '#FF9E01', '#FCD202', '#F8FF01',
               '#B0DE09', '#04D215', '#0D8ECF', '#0D52D1', '#2A0CD0')
   )
-  
-  # prepare value axes
+  ##Plot
   valueAxis_obj1 <- pipeR::pipeline(
     valueAxis(id = 'v1', title = 'valueAxis 1', position = 'left'),
     addListener('clickItem', 'function(event) {alert(\'Click on valueAxis 1\')}')
@@ -506,7 +494,7 @@ output$serial9 <- renderAmCharts({
   
   valueAxis_obj2 <- pipeR::pipeline(
     valueAxis(id = 'v2', title = 'valueAxis 2', position = 'right'),
-    addListener('clickItem', 'function(event) {alert(\'Click on valueAxis 2\')}')
+    addListener('clickItem', 'function(event) {Shiny.onInputChange(\'mydata\', event.value);}')
   )
   
   # build the chart
@@ -525,7 +513,7 @@ output$serial9 <- renderAmCharts({
 
 output$code_serial9 <- renderText({
   "
-  # prepare data
+  ##Data
   dp <- data.table(
     country = c('USA', 'China', 'Japan', 'Germany', 'UK', 'France',
                 'India', 'Spain', 'Netherlands', 'Russia'), 
@@ -534,7 +522,7 @@ output$code_serial9 <- renderText({
     color = c('#FF0F00', '#FF6600', '#FF9E01', '#FCD202', '#F8FF01',
               '#B0DE09', '#04D215', '#0D8ECF', '#0D52D1', '#2A0CD0')
   )
-
+  
   # prepare value axes
   valueAxis_obj1 <- pipeR::pipeline(
     valueAxis(id = 'v1', title = 'valueAxis 1', position = 'left'),
@@ -543,10 +531,10 @@ output$code_serial9 <- renderText({
   
   valueAxis_obj2 <- pipeR::pipeline(
     valueAxis(id = 'v2', title = 'valueAxis 2', position = 'right'),
-    addListener('clickItem', 'function(event) {alert(\'Click on valueAxis 2\')}')
-  )
+    addListener('clickItem', 'function(event) {Shiny.onInputChange(\'mydata\', event.value);}')
+    )
   
-  # build the chart
+  #Plot
   pipeR::pipeline(
     amSerialChart(categoryField = 'country', dataProvider = dp),
     addGraph(balloonText = '<b>[[category]]: [[value]]</b>', fillColorsField = 'color', valueAxis = 'v1',
@@ -561,3 +549,187 @@ output$code_serial9 <- renderText({
   "
 })
 
+output$results <- renderPrint({
+  input$mydata
+})
+
+# ---
+# Candle stick with chartScrollbar zoom
+# ---
+output$serial10 <- renderAmCharts({
+  ##Data
+  start <- as.POSIXct('01-01-2015', format = '%d-%m-%Y')
+  end <- as.POSIXct('31-12-2015', format = '%d-%m-%Y')
+  date <- seq.POSIXt(from = start, to = end, by = 'day')
+  date <- format(date, '%m-%d-%Y')
+  low <- c() ; open <- c() ; close <- c() ; high <- c() ; median <- c()
+  
+  n <- 100
+  invisible(
+    sapply(1:length(date), function(i)
+    {
+      sample <- rnorm(n, mean = sample(1:10, 1), sd = sample(1:10/10, 1))
+      quant <- boxplot(sample, plot = FALSE)$stats
+      low <<- c(low, quant[1])
+      open <<- c(open, quant[2])
+      median <<- c(median, quant[3])
+      close <<- c(close, quant[4])
+      high <<- c(high, quant[5])
+    })
+  )
+  dp <- data.table(date = date, low = round(low, 2), open = round(open, 2), 
+                   close = round(close, 2), high = round(high, 2), median = round(median, 2)) 
+  balloonText <- paste('Open:<b>[[open]]</b><br>',
+                       'Low:<b>[[low]]</b><br>',
+                       'High:<b>[[high]]</b><br>',
+                       'Close:<b>[[close]]</b><br>')
+  ##Plot
+  pipeline(
+    amSerialChart(categoryField = 'date', dataDateFormat = 'MM-DD-YYYY',
+                  dataProvider = dp, startDuration = 0),
+    setCategoryAxis(parseDates = TRUE),
+    addGraph(id = 'g1', type = 'candlestick', lineColor = '#7f8da9', lowField = 'low',
+             closeField = 'close', highField = 'high', openField = 'open',
+             valueField = 'median', balloonText = balloonText, title = 'Price: ',
+             lineColor = '#7f8da9', lineAlpha = 1, fillAlphas = 0.9, negativeBase = 5,
+             negativeFillColors = '#db4c3c', negativeLineColor = '#db4c3c'),
+    setChartCursor(valueLineEnabled = TRUE, valueLineBalloonEnabled = TRUE),
+    setChartScrollbar(graph = 'g1', graphType = 'line'),
+    addListener("init", paste('function(event) {',
+                              'var nbCandles = event.chart.dataProvider.length;',
+                              'event.chart.zoomToIndexes(20, 100);',
+                              ' }'))
+  )
+})
+
+output$code_serial10 <- renderText({
+  "
+  ##Data
+  start <- as.POSIXct('01-01-2015', format = '%d-%m-%Y')
+  end <- as.POSIXct('31-12-2015', format = '%d-%m-%Y')
+  date <- seq.POSIXt(from = start, to = end, by = 'day')
+  date <- format(date, '%m-%d-%Y')
+  low <- c() ; open <- c() ; close <- c() ; high <- c() ; median <- c()
+  
+  n <- 100
+  invisible(
+    sapply(1:length(date), function(i)
+    {
+      sample <- rnorm(n, mean = sample(1:10, 1), sd = sample(1:10/10, 1))
+      quant <- boxplot(sample, plot = FALSE)$stats
+      low <<- c(low, quant[1])
+      open <<- c(open, quant[2])
+      median <<- c(median, quant[3])
+      close <<- c(close, quant[4])
+      high <<- c(high, quant[5])
+    })
+  )
+  dp <- data.table(date = date, low = round(low, 2), open = round(open, 2), 
+                   close = round(close, 2), high = round(high, 2), median = round(median, 2)) 
+  balloonText <- paste('Open:<b>[[open]]</b><br>',
+                       'Low:<b>[[low]]</b><br>',
+                       'High:<b>[[high]]</b><br>',
+                       'Close:<b>[[close]]</b><br>')
+  ##Plot
+  pipeline(
+    amSerialChart(categoryField = 'date', dataDateFormat = 'MM-DD-YYYY',
+                  dataProvider = dp, startDuration = 0),
+    setCategoryAxis(parseDates = TRUE),
+    addGraph(id = 'g1', type = 'candlestick', lineColor = '#7f8da9', lowField = 'low',
+             closeField = 'close', highField = 'high', openField = 'open',
+             valueField = 'median', balloonText = balloonText, title = 'Price: ',
+             lineColor = '#7f8da9', lineAlpha = 1, fillAlphas = 0.9, negativeBase = 5,
+             negativeFillColors = '#db4c3c', negativeLineColor = '#db4c3c'),
+    setChartCursor(valueLineEnabled = TRUE, valueLineBalloonEnabled = TRUE),
+    setChartScrollbar(graph = 'g1', graphType = 'line'),
+    addListener('init', paste('function(event) {',
+                              'var nbCandles = event.chart.dataProvider.length;',
+                              'event.chart.zoomToIndexes(20, 100);',
+                              ' }'))
+  )
+  "
+})
+
+# ---
+# Stack bar with negative values
+# ---
+output$serial11 <- renderAmCharts({
+  ##Data
+  n <- 15
+  (male <- round(sort(runif(n)), 1))
+  (female <- -round(sort(runif(n)), 1))
+  (category <- factor(paste('cat.', 1:15)))
+  dataProvider <- data.table(male, female, category)
+  labelFunction1 <- htmlwidgets::JS('function(item) {',
+                                    'return Math.abs(item.values.value);',
+                                    '}')
+  balloonFunction <- htmlwidgets::JS('function(item) {',
+                                     'return item.category + \': \' + Math.abs(item.values.value) + \'%\';',
+                                     '}')
+  labelFunction2 <- htmlwidgets::JS('function(value) {',
+                                    'return Math.abs(value) + \'%\';',
+                                    '}')
+  
+  valueAxis_obj <- valueAxis(gridAlpha = 0, ignoreAxisWidth = TRUE, id = 'axis1',
+                             labelFunction = labelFunction2)
+  ##Plot
+  pipeline(
+    amSerialChart(startDuration = 0, rotate = TRUE, marginBottom = 50,
+                  categoryField = 'category'),
+    addGraph(fillAlphas = .8, lineAlpha = .2, type = 'column', valueField = 'male',
+             title = 'Male', clustered = FALSE, labelFunction = labelFunction1,
+             balloonFunction = balloonFunction),
+    addGraph(fillAlphas = .8, lineAlpha = .2, type = 'column', valueField = 'female',
+             title = 'Female', clustered = FALSE, labelFunction = labelFunction1,
+             balloonFunction = balloonFunction),
+    setCategoryAxis(gridPosition = 'start', gridAlpha = .2, axisAlpha = 0),
+    setBalloon(fixedPosition = TRUE),
+    setChartCursor(valueBalloonEnabled = FALSE, cursorAlpha = .05, fullWidth = TRUE),
+    addLabel(text = 'Male', x = '28%', y = '97%', bold = TRUE, align = 'middle'),
+    addLabel(text = 'Female', x = '75%', y = '97%', bold = TRUE, align = 'middle'),
+    addGuide(value = 0, lineAlpha = .2, valueAxis = 'axis1'),
+    setDataProvider(dataProvider = dataProvider)
+  )
+  
+})
+
+output$code_serial11 <- renderText({
+  "
+  ##Data
+  n <- 15
+  (male <- round(sort(runif(n)), 1))
+  (female <- -round(sort(runif(n)), 1))
+  (category <- factor(paste('cat.', 1:15)))
+  dataProvider <- data.table(male, female, category)
+  labelFunction1 <- htmlwidgets::JS('function(item) {',
+                                    'return Math.abs(item.values.value);',
+                                    '}')
+  balloonFunction <- htmlwidgets::JS('function(item) {',
+                                     'return item.category + \': \' + Math.abs(item.values.value) + \'%\';',
+                                     '}')
+  labelFunction2 <- htmlwidgets::JS('function(value) {',
+                                    'return Math.abs(value) + \'%\';',
+                                    '}')
+  
+  valueAxis_obj <- valueAxis(gridAlpha = 0, ignoreAxisWidth = TRUE, id = 'axis1',
+                             labelFunction = labelFunction2)
+  ##Plot
+  pipeline(
+    amSerialChart(startDuration = 0, rotate = TRUE, marginBottom = 50,
+                  categoryField = 'category'),
+    addGraph(fillAlphas = .8, lineAlpha = .2, type = 'column', valueField = 'male',
+             title = 'Male', clustered = FALSE, labelFunction = labelFunction1,
+             balloonFunction = balloonFunction),
+    addGraph(fillAlphas = .8, lineAlpha = .2, type = 'column', valueField = 'female',
+             title = 'Female', clustered = FALSE, labelFunction = labelFunction1,
+             balloonFunction = balloonFunction),
+    setCategoryAxis(gridPosition = 'start', gridAlpha = .2, axisAlpha = 0),
+    setBalloon(fixedPosition = TRUE),
+    setChartCursor(valueBalloonEnabled = FALSE, cursorAlpha = .05, fullWidth = TRUE),
+    addLabel(text = 'Male', x = '28%', y = '97%', bold = TRUE, align = 'middle'),
+    addLabel(text = 'Male', x = '75%', y = '97%', bold = TRUE, align = 'middle'),
+    addGuide(value = 0, lineAlpha = .2, valueAxis = 'axis1'),
+    setDataProvider(dataProvider = dataProvider)
+  )
+  "
+})
